Test mini-galleries — Python documentation

# Test mini-galleries

Test 1-N

Testing future statements across examples

Test 1-D-D

## Examples using `sphinx_gallery.sorting.ExplicitOrder`

Testing future statements across examples

Test 1-D-C

### Examples using `sphinx_gallery.sorting.ExplicitOrder`

Testing future statements across examples

Test 1-C-D

## This is a custom heading

Testing future statements across examples

Test 2-N

Testing future statements across examples

Link to other packages

Test 2-D-D

## Examples using one of multiple objects

Testing future statements across examples

Link to other packages

Test 2-C-C

# This is a different custom heading

Testing future statements across examples

Link to other packages